package com.os.ems.record.controller;

import java.text.ParseException;
import java.util.Date;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.os.common.core.page.PageDomain;
import com.os.common.core.page.TableSupport;
import org.checkerframework.checker.units.qual.A;
import org.springframework.format.annotation.DateTimeFormat;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.ems.record.domain.RecordIotenvInstant;
import com.os.ems.record.service.IRecordIotenvInstantService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 物联网数据Controller
 * 
 * @author zch
 * @date 2025-04-28
 */
@RestController
@RequestMapping("/ems/record/recordIotenvInstant")
public class RecordIotenvInstantController extends BaseController
{
    @Autowired
    private IRecordIotenvInstantService recordIotenvInstantService;

    /**
     * 查询物联网数据列表
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordIotenvInstant:list')")
    @GetMapping("/list")
    public TableDataInfo list (RecordIotenvInstant recordIotenvInstant)throws ParseException
    {
        PageDomain pageDomain = TableSupport.buildPageRequest();
        Integer pageNum = pageDomain.getPageNum();
        Integer pageSize = pageDomain.getPageSize();
        return recordIotenvInstantService.selectRecordIotenvInstantListWithPage(recordIotenvInstant,pageNum,pageSize);
    }


    /**
     * 导出物联网数据列表
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordIotenvInstant:export')")
    @Log(title = "物联网数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RecordIotenvInstant recordIotenvInstant)throws ParseException
    {
        List<RecordIotenvInstant> list = recordIotenvInstantService.selectRecordIotenvInstantList(recordIotenvInstant);
        ExcelUtil<RecordIotenvInstant> util = new ExcelUtil<RecordIotenvInstant>(RecordIotenvInstant.class);
        util.exportExcel(response, list, "物联网数据数据");
    }

    /**
     * 获取物联网数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordIotenvInstant:query')")
    @GetMapping(value = "/{objid}")
    public AjaxResult getInfo(@PathVariable("objid") Long objid)
    {
        return success(recordIotenvInstantService.selectRecordIotenvInstantByObjid(objid));
    }

    /**
     * 新增物联网数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordIotenvInstant:add')")
    @Log(title = "物联网数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RecordIotenvInstant recordIotenvInstant)
    {
        recordIotenvInstant.setCreateBy(getUsername());
        return toAjax(recordIotenvInstantService.insertRecordIotenvInstant(recordIotenvInstant));
    }

    /**
     * 修改物联网数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordIotenvInstant:edit')")
    @Log(title = "物联网数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RecordIotenvInstant recordIotenvInstant)
    {
        recordIotenvInstant.setUpdateBy(getUsername());
        return toAjax(recordIotenvInstantService.updateRecordIotenvInstant(recordIotenvInstant));
    }

    /**
     * 删除物联网数据
     */
    @PreAuthorize("@ss.hasPermi('ems/record:recordIotenvInstant:remove')")
    @Log(title = "物联网数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{objids}")
    public AjaxResult remove(@PathVariable Long[] objids)
    {
        return toAjax(recordIotenvInstantService.deleteRecordIotenvInstantByObjids(objids));
    }

    @PreAuthorize("@ss.hasPermi('ems/record:recordIotenvInstant:list')")
    @GetMapping("/getRecordIotenvInstantList")
    public AjaxResult getRecordIotenvInstantList (RecordIotenvInstant recordIotenvInstant)throws ParseException
    {
        List<RecordIotenvInstant> recordIotenvInstants = recordIotenvInstantService.selectRecordIotenvInstantList(recordIotenvInstant);
        return success(recordIotenvInstants);
    }
}
