package com.os.ems.record.mapper;

import java.util.Date;
import java.util.List;
import com.os.ems.record.domain.EmsRecordAlarmData;
import org.apache.ibatis.annotations.Param;

/**
 * 异常数据记录Mapper接口
 * 
 * @author Yinq
 * @date 2024-05-15
 */
public interface EmsRecordAlarmDataMapper 
{
    /**
     * 查询异常数据记录
     * 
     * @param objId 异常数据记录主键
     * @return 异常数据记录
     */
    public EmsRecordAlarmData selectEmsRecordAlarmDataByObjId(Long objId);

    /**
     * 查询异常数据记录列表
     * 
     * @param emsRecordAlarmData 异常数据记录
     * @return 异常数据记录集合
     */
    public List<EmsRecordAlarmData> selectEmsRecordAlarmDataList(EmsRecordAlarmData emsRecordAlarmData);

    /**
     * 新增异常数据记录
     * 
     * @param emsRecordAlarmData 异常数据记录
     * @return 结果
     */
    public int insertEmsRecordAlarmData(EmsRecordAlarmData emsRecordAlarmData);

    /**
     * 修改异常数据记录
     * 
     * @param emsRecordAlarmData 异常数据记录
     * @return 结果
     */
    public int updateEmsRecordAlarmData(EmsRecordAlarmData emsRecordAlarmData);

    /**
     * 删除异常数据记录
     * 
     * @param objId 异常数据记录主键
     * @return 结果
     */
    public int deleteEmsRecordAlarmDataByObjId(Long objId);

    /**
     * 批量删除异常数据记录
     * 
     * @param objIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteEmsRecordAlarmDataByObjIds(Long[] objIds);
    
    /**
     * 查询最近时间内的异常数据
     * 
     * @param fiveMinutesAgo 开始时间
     * @return 异常数据列表
     */
    public List<EmsRecordAlarmData> selectRecentAlarmData(@Param("fiveMinutesAgo") Date fiveMinutesAgo);
}
