package com.os.mes.base.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.mes.base.domain.BaseStaffInfo;
import com.os.mes.base.service.IBaseStaffInfoService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 员工信息Controller
 *
 * @author Yinq
 * @date 2024-05-15
 */
@RestController
@RequestMapping("/mes/base/baseStaffInfo")
public class BaseStaffInfoController extends BaseController {
    @Autowired
    private IBaseStaffInfoService baseStaffInfoService;

    /**
     * 查询员工信息列表
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseStaffInfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(BaseStaffInfo baseStaffInfo) {
        startPage();
        List<BaseStaffInfo> list = baseStaffInfoService.selectBaseStaffInfoList(baseStaffInfo);
        return getDataTable(list);
    }

    /**
     * 导出员工信息列表
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseStaffInfo:export')")
    @Log(title = "员工信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BaseStaffInfo baseStaffInfo) {
        List<BaseStaffInfo> list = baseStaffInfoService.selectBaseStaffInfoList(baseStaffInfo);
        ExcelUtil<BaseStaffInfo> util = new ExcelUtil<BaseStaffInfo>(BaseStaffInfo.class);
        util.exportExcel(response, list, "员工信息数据");
    }

    /**
     * 获取员工信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseStaffInfo:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(baseStaffInfoService.selectBaseStaffInfoByObjId(objId));
    }

    /**
     * 新增员工信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseStaffInfo:add')")
    @Log(title = "员工信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BaseStaffInfo baseStaffInfo) {
        baseStaffInfo.setCreateBy(getUsername());
        return toAjax(baseStaffInfoService.insertBaseStaffInfo(baseStaffInfo));
    }

    /**
     * 修改员工信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseStaffInfo:edit')")
    @Log(title = "员工信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BaseStaffInfo baseStaffInfo) {
        baseStaffInfo.setUpdateBy(getUsername());
        return toAjax(baseStaffInfoService.updateBaseStaffInfo(baseStaffInfo));
    }

    /**
     * 删除员工信息
     */
    @PreAuthorize("@ss.hasPermi('mes/base:baseStaffInfo:remove')")
    @Log(title = "员工信息", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(baseStaffInfoService.deleteBaseStaffInfoByObjIds(objIds));
    }
}
