package com.os.mes.record.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.os.common.annotation.Log;
import com.os.common.core.controller.BaseController;
import com.os.common.core.domain.AjaxResult;
import com.os.common.enums.BusinessType;
import com.os.mes.record.domain.RecordStaffAttendance;
import com.os.mes.record.service.IRecordStaffAttendanceService;
import com.os.common.utils.poi.ExcelUtil;
import com.os.common.core.page.TableDataInfo;

/**
 * 员工打卡记录Controller
 *
 * @author Yinq
 * @date 2024-05-24
 */
@RestController
@RequestMapping("/mes/record/recordStaffAttendance")
public class RecordStaffAttendanceController extends BaseController {
    @Autowired
    private IRecordStaffAttendanceService recordStaffAttendanceService;

    /**
     * 查询员工打卡记录列表
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffAttendance:list')")
    @GetMapping("/list")
    public TableDataInfo list(RecordStaffAttendance recordStaffAttendance) {
        startPage();
        List<RecordStaffAttendance> list = recordStaffAttendanceService.selectRecordStaffAttendanceList(recordStaffAttendance);
        return getDataTable(list);
    }

    /**
     * 导出员工打卡记录列表
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffAttendance:export')")
    @Log(title = "员工打卡记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, RecordStaffAttendance recordStaffAttendance) {
        List<RecordStaffAttendance> list = recordStaffAttendanceService.selectRecordStaffAttendanceList(recordStaffAttendance);
        ExcelUtil<RecordStaffAttendance> util = new ExcelUtil<RecordStaffAttendance>(RecordStaffAttendance.class);
        util.exportExcel(response, list, "员工打卡记录数据");
    }

    /**
     * 获取员工打卡记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffAttendance:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(recordStaffAttendanceService.selectRecordStaffAttendanceByObjId(objId));
    }

    /**
     * 新增员工打卡记录
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffAttendance:add')")
    @Log(title = "员工打卡记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody RecordStaffAttendance recordStaffAttendance) {
        recordStaffAttendance.setCreateBy(getUsername());
        return toAjax(recordStaffAttendanceService.insertRecordStaffAttendance(recordStaffAttendance));
    }

    /**
     * 修改员工打卡记录
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffAttendance:edit')")
    @Log(title = "员工打卡记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody RecordStaffAttendance recordStaffAttendance) {
        recordStaffAttendance.setUpdateBy(getUsername());
        return toAjax(recordStaffAttendanceService.updateRecordStaffAttendance(recordStaffAttendance));
    }

    /**
     * 删除员工打卡记录
     */
    @PreAuthorize("@ss.hasPermi('mes/record:recordStaffAttendance:remove')")
    @Log(title = "员工打卡记录", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(recordStaffAttendanceService.deleteRecordStaffAttendanceByObjIds(objIds));
    }
}
